@@ -12,7 +12,7 @@ from .models import *
 @task()
 def reset_trigrams():
     files = os.listdir(settings.TRIGRAM_PATH)
-    c2 = chord(delete_all.si())(group(load_trigram_file.si(f) for f in files))
+    c2 = (delete_all.si() | (group(load_trigram_file.si(f) for f in files)))
     res = c2()
     res.get()
 
